summaryrefslogtreecommitdiff
path: root/src/commands.h
diff options
context:
space:
mode:
authorGlenn Morris <rgm@gnu.org>2009-01-09 03:29:39 +0000
committerGlenn Morris <rgm@gnu.org>2009-01-09 03:29:39 +0000
commita31e445edbbc9e629fbc62a11e1a7fc0fd9fe6c7 (patch)
treebc3094abc16317e64039d7493fe033a644009346 /src/commands.h
parentd293848d9d01f87cb1d827dbb32d911508960b5a (diff)
downloademacs-a31e445edbbc9e629fbc62a11e1a7fc0fd9fe6c7.tar.gz
Update for last_command_char rename.
Diffstat (limited to 'src/commands.h')
-rw-r--r--src/commands.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/commands.h b/src/commands.h
index 3ade1e590cb..d5d88b804f4 100644
--- a/src/commands.h
+++ b/src/commands.h
@@ -45,10 +45,10 @@ extern Lisp_Object Vminibuffer_local_must_match_map;
and require a match */
extern Lisp_Object Vminibuffer_local_filename_must_match_map;
-/* Last character of last key sequence. */
-extern Lisp_Object last_command_char;
+/* Last input event read as a command. */
+extern Lisp_Object last_command_event;
-/* Last input character read as a command, not counting menus
+/* Last input event read as a command, not counting menus
reached by the mouse. */
extern Lisp_Object last_nonmenu_event;